==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/it.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Attività",
    "Due yesterday" : "Scaduta ieri",
    "Due today" : "Scade oggi",
    "Due tomorrow" : "Scade domani",
    "Due on" : "Scade il",
    "Started yesterday" : "Iniziata ieri",
    "Starts today" : "Inizia oggi",
    "Starts tomorrow" : "Inizia domani",
    "Started on" : "Iniziata il",
    "Starts on" : "Inizia il",
    "[Remind me yesterday at ]HH:mm" : "[Ricordami ieri alle ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Ricordami oggi alle ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Ricordami domani alle ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Ricordami il ]DD MMM YYYY,[ alle ]HH:mm",
    "Yesterday" : "Ieri",
    "Today" : "Oggi",
    "Tomorrow" : "Domani",
    "in %s" : "in %s",
    "%s ago" : "%s fa",
    "seconds" : "secondi",
    "a minute" : "un minuto",
    "%d minutes" : "%d minuti",
    "an hour" : "un'ora",
    "%d hours" : "%d ore",
    "a day" : "un giorno",
    "%d days" : "%d giorni",
    "a month" : "un mese",
    "%d months" : "%d mesi",
    "a year" : "un anno",
    "%d years" : "%d anni",
    "week" : "settimana",
    "weeks" : "settimane",
    "day" : "giorno",
    "days" : "giorni",
    "hour" : "ora",
    "hours" : "ore",
    "minute" : "minuto",
    "minutes" : "minuti",
    "second" : "secondo",
    "before beginning" : "prima dell'inizio",
    "after beginning" : "dopo l'inizio",
    "before end" : "prima della fine",
    "after end" : "dopo la fine",
    "Comment" : "Commento",
    "Add a comment" : "Aggiungi un commento",
    "This will delete the Calendar \"%s\" and all of its entries." : "Questo eliminerà il calendario \"%s\" e tutte le sue voci.",
    "The name \"%s\" is already used." : "Il nome \"%s\" è già utilizzato.",
    "An empty name is not allowed." : "Un nome vuoto non è consentito.",
    "Hidden" : "Nascosto",
    "Visible" : "Visibile",
    "Automatic" : "Automatico",
    "Sunday" : "Domenica",
    "Monday" : "Lunedì",
    "Tuesday" : "Martedì",
    "Wednesday" : "Mercoledì",
    "Thursday" : "Giovedì",
    "Friday" : "Venerdì",
    "Saturday" : "Sabato",
    "Add an important item in \"%s\"..." : "Aggiungi un elemento importante in \"%s\"...",
    "Add an item due today in \"%s\"..." : "Aggiungi un elemento che scade oggi in \"%s\"...",
    "Add an item in \"%s\"..." : "Aggiungi un elemento in \"%s\"...",
    "Add a current item in \"%s\"..." : "Aggiungi un elemento corrente in \"%s\"...",
    "Add a subtask to \"%s\"..." : "Aggiungi una sottoattività a \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n attività completata","%n attività completate"],
    "Hours" : "Ore",
    "Minutes" : "Minuti",
    "Set due date" : "Imposta data di scadenza",
    "%s %% completed" : "%s %% completato",
    "priority %s: " : "priorità %s: ",
    "high" : "alta",
    "medium" : "media",
    "low" : "bassa",
    "no priority assigned" : "nessuna priorità assegnata",
    "Remind me" : "Ricordami",
    "at the end" : "alla fine",
    "at the beginning" : "all'inizio",
    "Set start date" : "Imposta data iniziale",
    "{calendar} shared by {owner}" : "{calendar} condiviso da {owner}",
    "Unnamed" : "Senza nome",
    "Important" : "Importante",
    "Week" : "Settimana",
    "All" : "Tutti",
    "Current" : "Attuale",
    "Completed" : "Completato",
    "Delete" : "Elimina",
    "Cancel" : "Annulla",
    "Edit" : "Modifica",
    "Link" : "Collegamento",
    "Download" : "Scarica",
    "Save" : "Salva",
    "Add List..." : "Aggiungi elenco...",
    "New List" : "Nuovo elenco",
    "Settings" : "Impostazioni",
    "Start of week" : "Inizio della settimana",
    "Visibility of Smart Collections" : "Visibilità delle collezioni veloci",
    "Change sort order" : "Cambia l'ordinamento",
    "Default" : "Predefinito",
    "Due date" : "Data di scadenza",
    "Start date" : "Data iniziale",
    "Priority" : "Priorità",
    "Alphabetically" : "Ordine alfabetico",
    "Manually" : "Manuale",
    "Load remaining completed tasks." : "Carica le attività completate rimanenti.",
    "All day" : "Tutto il giorno",
    "(New category)" : "(Nuova categoria)",
    "Select categories..." : "Seleziona le categorie...",
    "Loading the task..." : "Caricamento attività in corso...",
    "Task not found!" : "Attività non trovata!",
    "add a subtask to" : "aggiungi una sottoattività a"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/it.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Attività",
    "Due yesterday" : "Scaduta ieri",
    "Due today" : "Scade oggi",
    "Due tomorrow" : "Scade domani",
    "Due on" : "Scade il",
    "Started yesterday" : "Iniziata ieri",
    "Starts today" : "Inizia oggi",
    "Starts tomorrow" : "Inizia domani",
    "Started on" : "Iniziata il",
    "Starts on" : "Inizia il",
    "[Remind me yesterday at ]HH:mm" : "[Ricordami ieri alle ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Ricordami oggi alle ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Ricordami domani alle ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Ricordami il ]DD MMM YYYY,[ alle ]HH:mm",
    "Yesterday" : "Ieri",
    "Today" : "Oggi",
    "Tomorrow" : "Domani",
    "in %s" : "in %s",
    "%s ago" : "%s fa",
    "seconds" : "secondi",
    "a minute" : "un minuto",
    "%d minutes" : "%d minuti",
    "an hour" : "un'ora",
    "%d hours" : "%d ore",
    "a day" : "un giorno",
    "%d days" : "%d giorni",
    "a month" : "un mese",
    "%d months" : "%d mesi",
    "a year" : "un anno",
    "%d years" : "%d anni",
    "week" : "settimana",
    "weeks" : "settimane",
    "day" : "giorno",
    "days" : "giorni",
    "hour" : "ora",
    "hours" : "ore",
    "minute" : "minuto",
    "minutes" : "minuti",
    "second" : "secondo",
    "before beginning" : "prima dell'inizio",
    "after beginning" : "dopo l'inizio",
    "before end" : "prima della fine",
    "after end" : "dopo la fine",
    "Comment" : "Commento",
    "Add a comment" : "Aggiungi un commento",
    "This will delete the Calendar \"%s\" and all of its entries." : "Questo eliminerà il calendario \"%s\" e tutte le sue voci.",
    "The name \"%s\" is already used." : "Il nome \"%s\" è già utilizzato.",
    "An empty name is not allowed." : "Un nome vuoto non è consentito.",
    "Hidden" : "Nascosto",
    "Visible" : "Visibile",
    "Automatic" : "Automatico",
    "Sunday" : "Domenica",
    "Monday" : "Lunedì",
    "Tuesday" : "Martedì",
    "Wednesday" : "Mercoledì",
    "Thursday" : "Giovedì",
    "Friday" : "Venerdì",
    "Saturday" : "Sabato",
    "Add an important item in \"%s\"..." : "Aggiungi un elemento importante in \"%s\"...",
    "Add an item due today in \"%s\"..." : "Aggiungi un elemento che scade oggi in \"%s\"...",
    "Add an item in \"%s\"..." : "Aggiungi un elemento in \"%s\"...",
    "Add a current item in \"%s\"..." : "Aggiungi un elemento corrente in \"%s\"...",
    "Add a subtask to \"%s\"..." : "Aggiungi una sottoattività a \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n attività completata","%n attività completate"],
    "Hours" : "Ore",
    "Minutes" : "Minuti",
    "Set due date" : "Imposta data di scadenza",
    "%s %% completed" : "%s %% completato",
    "priority %s: " : "priorità %s: ",
    "high" : "alta",
    "medium" : "media",
    "low" : "bassa",
    "no priority assigned" : "nessuna priorità assegnata",
    "Remind me" : "Ricordami",
    "at the end" : "alla fine",
    "at the beginning" : "all'inizio",
    "Set start date" : "Imposta data iniziale",
    "{calendar} shared by {owner}" : "{calendar} condiviso da {owner}",
    "Unnamed" : "Senza nome",
    "Important" : "Importante",
    "Week" : "Settimana",
    "All" : "Tutti",
    "Current" : "Attuale",
    "Completed" : "Completato",
    "Delete" : "Elimina",
    "Cancel" : "Annulla",
    "Edit" : "Modifica",
    "Link" : "Collegamento",
    "Download" : "Scarica",
    "Save" : "Salva",
    "Add List..." : "Aggiungi elenco...",
    "New List" : "Nuovo elenco",
    "Settings" : "Impostazioni",
    "Start of week" : "Inizio della settimana",
    "Visibility of Smart Collections" : "Visibilità delle collezioni veloci",
    "Change sort order" : "Cambia l'ordinamento",
    "Default" : "Predefinito",
    "Due date" : "Data di scadenza",
    "Start date" : "Data iniziale",
    "Priority" : "Priorità",
    "Alphabetically" : "Ordine alfabetico",
    "Manually" : "Manuale",
    "Load remaining completed tasks." : "Carica le attività completate rimanenti.",
    "Task is completed" : "L'attività è completata",
    "All day" : "Tutto il giorno",
    "(New category)" : "(Nuova categoria)",
    "Select categories..." : "Seleziona le categorie...",
    "Loading the task..." : "Caricamento attività in corso...",
    "Task not found!" : "Attività non trovata!",
    "add a subtask to" : "aggiungi una sottoattività a",
    "Toggle subtasks" : "Commuta sottoattività ",
    "Toggle completed subtasks" : "Commuta le sottoattività completate"
},
"nplurals=2; plural=(n != 1);");
